@@ -4,5 +4,5 @@ from .. import Provider as BankProvider
 class Provider(BankProvider):
     """Implement bank provider for ``no_NO`` locale."""
 
-    bban_format = '###########'
-    country_code = 'NO'
+    bban_format = "###########"
+    country_code = "NO"
